@@ -27,8 +27,7 @@
 #ifndef NAUTILUS_FILE_OPERATIONS_H
 #define NAUTILUS_FILE_OPERATIONS_H
 
-#include <gdk/gdkdnd.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 #include <gio/gio.h>
 
 typedef void (* NautilusCopyCallback)      (GHashTable *debuting_uris,
@@ -93,7 +92,7 @@ void nautilus_file_operations_unmount_mount (GtkWindow                      *par
 					     gboolean                        check_trash);
 void nautilus_file_operations_mount_volume  (GtkWindow                      *parent_window,
 					     GVolume                        *volume,
-					     gboolean                        inhibit_autorun);
+					     gboolean                        allow_autorun);
 								
 
 void nautilus_file_operations_copy      (GList                *files,
