@@ -95,7 +95,8 @@ static EelEnumerationEntry file_size_enum_entries[] = {
 	{ "3145728",	    N_("3 MB"),		3145728 },
 	{ "5242880",	    N_("5 MB"),		5242880 },
 	{ "10485760",	    N_("10 MB"),	10485760 },
-	{ "104857600",	    N_("100 MB"),	104857600 }
+	{ "104857600",	    N_("100 MB"),	104857600 },
+	{ "1073741824",     N_("1 GB"),         1073741824 }
 };
 
 static EelEnumerationEntry click_policy_enum_entries[] = {
@@ -137,6 +138,7 @@ static EelEnumerationEntry search_bar_type_enum_entries[] = {
 
 static EelEnumerationEntry default_folder_viewer_enum_entries[] = {
 	{ "icon_view",	    N_("Icon View"),	NAUTILUS_DEFAULT_FOLDER_VIEWER_ICON_VIEW },
+	{ "compact_view",   N_("Compact View"),	NAUTILUS_DEFAULT_FOLDER_VIEWER_COMPACT_VIEW },
 	{ "list_view",	    N_("List View"),	NAUTILUS_DEFAULT_FOLDER_VIEWER_LIST_VIEW }
 };
 
@@ -284,7 +286,7 @@ static const PreferenceDefault preference_defaults[] = {
 	},
 	{ NAUTILUS_PREFERENCES_IMAGE_FILE_THUMBNAIL_LIMIT,
 	  PREFERENCE_INTEGER,
-	  GINT_TO_POINTER(3145728),
+	  GINT_TO_POINTER(10485760),
 	  NULL, NULL,
 	  "file_size"
 	},
@@ -415,6 +417,14 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_INTEGER,
 	  GINT_TO_POINTER (96)
 	},
+
+	/* Compact Icon View Default Preferences */
+	{ NAUTILUS_PREFERENCES_COMPACT_VIEW_DEFAULT_ZOOM_LEVEL,
+	  PREFERENCE_STRING,
+	  "standard",
+	  NULL, NULL,
+	  "default_zoom_level"
+	},
 	
 	/* List View Default Preferences */
 	{ NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_SORT_ORDER,
@@ -706,6 +716,8 @@ nautilus_global_preferences_get_default_folder_viewer_preference_as_iid (void)
 
 	if (preference_value == NAUTILUS_DEFAULT_FOLDER_VIEWER_LIST_VIEW) {
 		viewer_iid = NAUTILUS_LIST_VIEW_IID;
+	} else if (preference_value == NAUTILUS_DEFAULT_FOLDER_VIEWER_COMPACT_VIEW) {
+		viewer_iid = NAUTILUS_COMPACT_VIEW_IID;
 	} else {
 		viewer_iid = NAUTILUS_ICON_VIEW_IID;
 	}
